Skip to contents

Securely store the email and password to your Dr Frost Maths account so that it can be used between sessions. The keyring package is used as a backend, meaning that credentials are stored securely and permanently.

Usage

dr_frost_account(email, keyring = NULL)

Arguments

email

The email for your Dr Frost Account. Multiple accounts with different emails can be stored.

keyring

A string, passed into keyring::key_set() and keyring::key_get(). Use this to store your Dr Frost credentials on a custom keyring.

Value

Nothing. This function is called for its side effects.

Details

Calling this function should open a prompt, allowing you to enter your password securely.

To change the password stored for a specific email, just call the function again with the same email.

If the account you store is the first to be stored on the specified keyring, the account will be marked as a 'default' for the keyring. This means that when perform_tasks() is called without specifying an email, this account will be used as a default. Change this with set_default_account().

This means that once you have stored an account, the perform_tasks() function can be called without specifying an email or password.

Examples

if (FALSE) {
  dr_frost_account("YOUR-EMAIL")
  perform_tasks()
}