Skip to contents

Set or change the default email used by the perform_tasks() function.

Usage

set_default_account(email, keyring = NULL)

Arguments

email

The email to use.

keyring

A string, passed into keyring::key_set() and keyring::key_get(). Use this if your Dr Frost accounts are stored on a custom keyring.

Value

Nothing. This function is called for its side effects.

Examples

if (FALSE) {
  set_default_account("YOUR-EMAIL")
}