The dr_frost_tasks() object has an enhanced printing method, using topics and
subtopics as headers.
Usage
# S3 method for dr_frost_tasks
print(x, ..., n = 10)Arguments
- x
A
dr_frost_tasksobject.- ...
Not used.
- n
The maximum number of tasks to show. Excess tasks will be truncated. Use
Infto show all tasks.
Details
This printing method is heavily inspired by the tibble printing method:
tibble::print.tbl_df().
Examples
print(dr_frost_tasks())
#> # 30 Dr Frost tasks
#>
#> ── Algebra ─────────────────────────────────────────────────────────────────────
#>
#> ── Sequences ──
#> • continue_sequence
#> Continue a sequence.
#> • later_terms
#> Find terms of a sequence given a term-to-term rule.
#>
#> ── Solving Equations ──
#> • simple_substitution
#> Substitute into simple expressions (limited to addition, subtraction,
#> division, multiplication).
#> • solve_one_step
#> Solve linear equations where the variable appears on one side of the equation
#> only.
#>
#> ── Data Handling & Probability ─────────────────────────────────────────────────
#>
#> ── Averages and Range ──
#> • mean
#> Calculate the mean as an average.
#>
#> ── Data Representation ──
#> • pictograms
#> Interpret a pictogram.
#> • bar_charts
#> Bar Charts
#> • bank_statements
#> Complete a bank statement.
#> • pie_charts
#> Pie Charts
#>
#> ── Number ──────────────────────────────────────────────────────────────────────
#>
#> ── Arithmetic Operations ──
#> • addition_subtraction
#> Add and subtract whole numbers.
#> … with 20 more tasks
#> # ℹ Use `print(n = ...)` to see more tasks
print(dr_frost_tasks(), n = 5)
#> # 30 Dr Frost tasks
#>
#> ── Algebra ─────────────────────────────────────────────────────────────────────
#>
#> ── Sequences ──
#> • continue_sequence
#> Continue a sequence.
#> • later_terms
#> Find terms of a sequence given a term-to-term rule.
#>
#> ── Solving Equations ──
#> • simple_substitution
#> Substitute into simple expressions (limited to addition, subtraction,
#> division, multiplication).
#> • solve_one_step
#> Solve linear equations where the variable appears on one side of the equation
#> only.
#>
#> ── Data Handling & Probability ─────────────────────────────────────────────────
#>
#> ── Averages and Range ──
#> • mean
#> Calculate the mean as an average.
#> … with 25 more tasks
#> # ℹ Use `print(n = ...)` to see more tasks