Set or change the default email used by the perform_tasks() function.
Arguments
The email to use.
- keyring
A string, passed into
keyring::key_set()andkeyring::key_get(). Use this if your Dr Frost accounts are stored on a custom keyring.
Set or change the default email used by the perform_tasks() function.
The email to use.
A string, passed into keyring::key_set() and
keyring::key_get(). Use this if your Dr Frost accounts are
stored on a custom keyring.